Struct
QmiMessagePdsSetAgpsConfigInput
since: 1.12
Description [src]
struct QmiMessagePdsSetAgpsConfigInput {
/* No available fields */
}
The QmiMessagePdsSetAgpsConfigInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.12
Constructors
qmi_message_pds_set_agps_config_input_new
Allocates a new QmiMessagePdsSetAgpsConfigInput.
since: 1.12
Instance methods
qmi_message_pds_set_agps_config_input_get_location_server_address
Get the ‘Location Server Address’ field from self.
since: 1.12
qmi_message_pds_set_agps_config_input_get_location_server_url
Get the ‘Location Server URL’ field from self.
since: 1.12
qmi_message_pds_set_agps_config_input_get_network_mode
Get the ‘Network Mode’ field from self.
since: 1.12
qmi_message_pds_set_agps_config_input_ref
Atomically increments the reference count of self by one.
since: 1.12
qmi_message_pds_set_agps_config_input_set_location_server_address
Set the ‘Location Server Address’ field in the message.
since: 1.12
qmi_message_pds_set_agps_config_input_set_location_server_url
Set the ‘Location Server URL’ field in the message.
since: 1.12
qmi_message_pds_set_agps_config_input_set_network_mode
Set the ‘Network Mode’ field in the message.
since: 1.12
qmi_message_pds_set_agps_config_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.12